@@ -2212,3 +2212,10 @@ class Builder(Update):
 
     def is_update_action(self, action):
         return action == Actions.Update
+
+    def remove_machine_id(self, builder_path):
+        try:
+            os.unlink(path.join(builder_path, 'etc/machine-id'))
+            return True
+        except OSError as e:
+            raise BuilderError(_("failed to find /etc/machine-id"))
